aboutsummaryrefslogtreecommitdiffstats
path: root/drivers/staging/wlan-ng/hfa384x_usb.c
diff options
context:
space:
mode:
authorSergio Paracuellos <sergio.paracuellos@gmail.com>2016-09-28 20:20:14 +0200
committerGreg Kroah-Hartman <gregkh@linuxfoundation.org>2016-10-02 17:03:56 +0200
commit501f5f96b3bd70348c5e9f71f3c17ddbab73522d (patch)
tree27fcca196433d631faf61ebb200dce3109b8e949 /drivers/staging/wlan-ng/hfa384x_usb.c
parentstaging: wlang-ng: avoid new typedef: hfa384x_pdrec_t (diff)
downloadlinux-dev-501f5f96b3bd70348c5e9f71f3c17ddbab73522d.tar.xz
linux-dev-501f5f96b3bd70348c5e9f71f3c17ddbab73522d.zip
staging: wlang-ng: avoid new typedef: hfa384x_cmdresult_t
This patch fixes the following checkpatch.pl warning in hfa384x.h: WARNING: do not add new typedefs It applies for typedef hfa384x_cmdresult_t Signed-off-by: Sergio Paracuellos <sergio.paracuellos@gmail.com> Signed-off-by: Greg Kroah-Hartman <gregkh@linuxfoundation.org>
Diffstat (limited to 'drivers/staging/wlan-ng/hfa384x_usb.c')
-rw-r--r--drivers/staging/wlan-ng/hfa384x_usb.c16
1 files changed, 8 insertions, 8 deletions
diff --git a/drivers/staging/wlan-ng/hfa384x_usb.c b/drivers/staging/wlan-ng/hfa384x_usb.c
index 9203880ba970..1e5f74c3a218 100644
--- a/drivers/staging/wlan-ng/hfa384x_usb.c
+++ b/drivers/staging/wlan-ng/hfa384x_usb.c
@@ -213,7 +213,7 @@ static void hfa384x_cb_status(hfa384x_t *hw, const hfa384x_usbctlx_t *ctlx);
static int
usbctlx_get_status(const struct hfa384x_usb_statusresp *cmdresp,
- hfa384x_cmdresult_t *result);
+ struct hfa384x_cmdresult *result);
static void
usbctlx_get_rridresult(const struct hfa384x_usb_rridresp *rridresp,
@@ -622,7 +622,7 @@ static hfa384x_usbctlx_t *usbctlx_alloc(void)
static int
usbctlx_get_status(const struct hfa384x_usb_statusresp *cmdresp,
- hfa384x_cmdresult_t *result)
+ struct hfa384x_cmdresult *result)
{
result->status = le16_to_cpu(cmdresp->status);
result->resp0 = le16_to_cpu(cmdresp->resp0);
@@ -647,13 +647,13 @@ usbctlx_get_rridresult(const struct hfa384x_usb_rridresp *rridresp,
/*----------------------------------------------------------------
* Completor object:
* This completor must be passed to hfa384x_usbctlx_complete_sync()
-* when processing a CTLX that returns a hfa384x_cmdresult_t structure.
+* when processing a CTLX that returns a struct hfa384x_cmdresult structure.
----------------------------------------------------------------*/
struct usbctlx_cmd_completor {
struct usbctlx_completor head;
const struct hfa384x_usb_statusresp *cmdresp;
- hfa384x_cmdresult_t *result;
+ struct hfa384x_cmdresult *result;
};
static inline int usbctlx_cmd_completor_fn(struct usbctlx_completor *head)
@@ -669,7 +669,7 @@ static inline struct usbctlx_completor *init_cmd_completor(
*completor,
const struct hfa384x_usb_statusresp
*cmdresp,
- hfa384x_cmdresult_t *result)
+ struct hfa384x_cmdresult *result)
{
completor->head.complete = usbctlx_cmd_completor_fn;
completor->cmdresp = cmdresp;
@@ -798,7 +798,7 @@ static inline struct usbctlx_completor *init_rmem_completor(
static void hfa384x_cb_status(hfa384x_t *hw, const hfa384x_usbctlx_t *ctlx)
{
if (ctlx->usercb) {
- hfa384x_cmdresult_t cmdresult;
+ struct hfa384x_cmdresult cmdresult;
if (ctlx->state != CTLX_COMPLETE) {
memset(&cmdresult, 0, sizeof(cmdresult));
@@ -1497,7 +1497,7 @@ hfa384x_dowrid(hfa384x_t *hw,
kfree(ctlx);
} else if (mode == DOWAIT) {
struct usbctlx_cmd_completor completor;
- hfa384x_cmdresult_t wridresult;
+ struct hfa384x_cmdresult wridresult;
result = hfa384x_usbctlx_complete_sync(hw,
ctlx,
@@ -1679,7 +1679,7 @@ hfa384x_dowmem(hfa384x_t *hw,
kfree(ctlx);
} else if (mode == DOWAIT) {
struct usbctlx_cmd_completor completor;
- hfa384x_cmdresult_t wmemresult;
+ struct hfa384x_cmdresult wmemresult;
result = hfa384x_usbctlx_complete_sync(hw,
ctlx,